<template>
	<transition name="slideFade">
		<div
			v-show="showBanner"
			class="campaign-bar py-0 px-1 px-md-2"
			id="campaign-bar"
			:class="{ 'negative-margin': negativeMargin }"
		>
			<div></div>
			<div>
				<span>{{ text }}</span>
				<a v-if="url && link" :href="url">
					{{ link }}
				</a>
			</div>
			<svg class="ok-icon" @click="removeCampaignBar">
				<use :xlink:href="iconUrl + '#ok-icon-close'"></use>
			</svg>
		</div>
	</transition>
</template>

<script>
	module.exports = {
		data() {
			return {
				background: "",
				campaign: "",
				campaignLoaded: false,
				link: "",
				text: "",
				translateY: false,
				url: "",
			};
		},
		store,
		props: ["iconUrl"],
		methods: {
			getCampaign() {
				this.$http.get("promotionbar/index/promotionbar", {}).then(response => {
					const { backgroundColor, name, buttonText, text, buttonUrl } =
						response.body.promotionbar;

					this.background = backgroundColor;
					this.campaign = name;
					this.link = buttonText;
					this.text = text;
					this.url = buttonUrl;

					if (text && name && backgroundColor) {
						this.campaignLoaded = true;
					}
				});
			},
			removeCampaignBar() {
				this.$cookies.set(this.campaign, "", "2D");
				this.campaignLoaded = false;
			},
		},
		mounted() {
			this.getCampaign();
		},
		computed: {
			cookieIsSet() {
				return this.$cookies.isKey(this.campaign);
			},
			negativeMargin() {
				return this.popMenuOrFilterOpen;
			},
			popMenuOrFilterOpen() {
				return (
					this.$store.getters.getPopState("navMenu") ||
					this.$store.getters.getPopState("filters")
				);
			},
			showBanner() {
				return (
					this.campaignLoaded &&
					!this.cookieIsSet &&
					!document.getElementById("osc") &&
					!document.getElementById("cart")
				);
			},
		},
		watch: {
			background(val) {
				document.getElementById("campaign-bar").style.backgroundColor = val;
			},
			showBanner() {
				this.$store.commit("setTopBarState", this.showBanner);
			},
		},
		created() {
			window.addEventListener("scroll", this.handleScroll);
		},
	};
</script>

<style>
	.campaign-bar {
		font-family: "Lato", sans-serif;
		background: #299065;
		color: #fff;
		text-transform: uppercase;
		height: 40px;
		line-height: 40px;
		display: flex;
		justify-content: space-between;
		font-size: 14px;
		align-items: center;
		top: 0;
		position: sticky;
		z-index: 995;
		width: 100%;
	}

	.campaign-bar.negative-margin {
		margin-top: -40px;
	}

	.campaign-bar a {
		color: #fff !important;
		margin-left: 5px;
		font-family: "Lato", sans-serif;
		text-decoration: underline;
	}
	.campaign-bar svg {
		cursor: pointer;
		fill: #fff !important;
		width: 15px;
		height: 15px;
		margin-left: 5px;
	}
	.campaign-bar .cls-1 {
		fill: #fff !important;
	}
	#main-header {
		top: 0;
	}

	@media (max-width: 1023px) {
		.campaign-bar {
			font-size: 12px;
			line-height: normal;
		}
	}
</style>
